@@ -27,7 +27,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-document.c,v 1.126 2006/01/19 18:16:00 paolo Exp $
+ * $Id: gedit-document.c,v 1.129 2006/02/12 22:02:04 pborelli Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -1073,9 +1073,7 @@ document_saver_saving (GeditDocumentSaver *saver,
 		       const GError       *error,
 		       GeditDocument      *doc)
 {
-	/* FIXME */
-	if (error)
-		g_print ("error saving: %s\n", error->message);
+	gedit_debug (DEBUG_DOCUMENT);
 
 	if (completed)
 	{
@@ -1096,9 +1094,9 @@ document_saver_saving (GeditDocumentSaver *saver,
 
 			gtk_text_buffer_set_modified (GTK_TEXT_BUFFER (doc),
 						      FALSE);
-			
+
 			set_uri (doc, uri, mime_type);
-			
+
 			set_encoding (doc, 
 				      doc->priv->requested_encoding, 
 				      TRUE);
@@ -1259,13 +1257,19 @@ gedit_document_goto_line (GeditDocument *doc,
 
 	line_count = gtk_text_buffer_get_line_count (GTK_TEXT_BUFFER (doc));
 
-	if (line > line_count)
+	if (line >= line_count)
 	{
 		ret = FALSE;
-		line = line_count;
+		gtk_text_buffer_get_end_iter (GTK_TEXT_BUFFER (doc),
+					      &iter);
+	}
+	else
+	{
+		gtk_text_buffer_get_iter_at_line (GTK_TEXT_BUFFER (doc),
+						  &iter,
+						  line);
 	}
 
-	gtk_text_buffer_get_iter_at_line (GTK_TEXT_BUFFER (doc), &iter, line);
 	gtk_text_buffer_place_cursor (GTK_TEXT_BUFFER (doc), &iter);
 
 	return ret;
@@ -1536,8 +1540,10 @@ gedit_document_replace_all (GeditDocument       *doc,
 	gchar *search_text;
 	gchar *replace_text;
 	gint replace_text_len;
-	GtkTextBuffer *buffer;	
-	
+	GtkTextBuffer *buffer;
+	gboolean check_brackets;
+	gboolean search_highliting;
+
 	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), 0);
 	g_return_val_if_fail (replace != NULL, 0);
 	g_return_val_if_fail ((find != NULL) || (doc->priv->search_text != NULL), 0);
@@ -1548,18 +1554,18 @@ gedit_document_replace_all (GeditDocument       *doc,
 		search_text = g_strdup (doc->priv->search_text);
 	else
 		search_text = gedit_utils_unescape_search_text (find);
-		
+
 	replace_text = gedit_utils_unescape_search_text (replace);
-		
+
 	gtk_text_buffer_get_start_iter (buffer, &iter);
-		
+
 	search_flags = GTK_SOURCE_SEARCH_VISIBLE_ONLY | GTK_SOURCE_SEARCH_TEXT_ONLY;
 
 	if (!GEDIT_SEARCH_IS_CASE_SENSITIVE (flags))
 	{
 		search_flags = search_flags | GTK_SOURCE_SEARCH_CASE_INSENSITIVE;
 	}
-	
+
 	replace_text_len = strlen (replace_text);
 
 	/* disable cursor_moved emission until the end of the
@@ -1568,8 +1574,16 @@ gedit_document_replace_all (GeditDocument       *doc,
 	 */
 	doc->priv->stop_cursor_moved_emission = TRUE;
 
+	/* also avoid spending time matching brackets */
+	check_brackets = gtk_source_buffer_get_check_brackets (GTK_SOURCE_BUFFER (buffer));
+	gtk_source_buffer_set_check_brackets (GTK_SOURCE_BUFFER (buffer), FALSE);
+
+	/* and do search highliting later */
+	search_highliting = gedit_document_get_enable_search_highlighting (doc);
+	gedit_document_set_enable_search_highlighting (doc, FALSE);
+
 	gtk_text_buffer_begin_user_action (buffer);
-	
+
 	do
 	{
 		found = gtk_source_iter_forward_search (&iter,
@@ -1578,29 +1592,28 @@ gedit_document_replace_all (GeditDocument       *doc,
                         	                	&m_start, 
                         	                	&m_end,
                                 	               	NULL);
-								      	               	
+
 		if (found && GEDIT_SEARCH_IS_ENTIRE_WORD (flags))
 		{
 			gboolean word;
-						
+
 			word = gtk_text_iter_starts_word (&m_start) && 
 			       gtk_text_iter_ends_word (&m_end);
-				
+
 			if (!word)
 			{
 				iter = m_end;
 				continue;
 			}
 		}
-		
+
 		if (found)
 		{
 			++cont;
-			
+
 			gtk_text_buffer_delete (buffer, 
 						&m_start,
 						&m_end);
-		
 			gtk_text_buffer_insert (buffer,
 						&m_start,
 						replace_text,
@@ -1619,13 +1632,17 @@ gedit_document_replace_all (GeditDocument       *doc,
 	doc->priv->stop_cursor_moved_emission = FALSE;
 	emit_cursor_moved (doc);
 
+	gtk_source_buffer_set_check_brackets (GTK_SOURCE_BUFFER (buffer),
+					      check_brackets);
+	gedit_document_set_enable_search_highlighting (doc, search_highliting);
+
 	g_free (search_text);
-	g_free (replace_text);	
+	g_free (replace_text);
 
 	return cont;
-}			    
+}
 
-void 
+void
 gedit_document_set_language (GeditDocument     *doc, 
 			     GtkSourceLanguage *lang)
 {
