@@ -123,6 +123,7 @@ static GeditLanguage known_languages [] =
 	{"mi", N_("Maori")},
 	{"mk", N_("Macedonian")},
 	{"mn", N_("Mongolian")},
+	{"mr", N_("Marathi")},
 	{"ms", N_("Malay")},
 	{"mt", N_("Maltese")},
 	{"nb", N_("Norwegian Bokmal")},
@@ -325,7 +326,6 @@ gedit_spell_checker_class_init (GeditSpellCheckerClass * klass)
 			  0); 
 }
 
-
 static void
 gedit_spell_checker_init (GeditSpellChecker *spell_checker)
 {
@@ -346,7 +346,6 @@ gedit_spell_checker_new	(void)
 	return spell;
 }
 
-
 static void 
 gedit_spell_checker_finalize (GObject *object)
 {
@@ -360,26 +359,26 @@ gedit_spell_checker_finalize (GObject *object)
 		delete_pspell_manager (spell_checker->manager);
 }
 
-static const GeditLanguage*
+static const GeditLanguage *
 get_language_from_abrev (const gchar *abrev)
 {
+	const GSList *langs;
+
 	g_return_val_if_fail (abrev != NULL, NULL);
 
-	const GSList *langs;
 	langs = gedit_spell_checker_get_available_languages ();
 
 	while (langs != NULL)
 	{
 		const GeditLanguage *l = (const GeditLanguage *)langs->data;
 
-		if (g_ascii_strncasecmp (abrev, l->abrev, strlen(l->abrev)) == 0)
+		if (g_ascii_strncasecmp (abrev, l->abrev, strlen (l->abrev)) == 0)
 			return l;
 
 		langs = g_slist_next (langs);
 	}
 
 	return NULL;
-	
 }
 
 gchar *
@@ -449,7 +448,8 @@ lazy_init (GeditSpellChecker *spell, const GeditLanguage *language, GError **err
 	{
 		const GSList *langs;
 		langs = gedit_spell_checker_get_available_languages ();
-		spell->active_lang = (const GeditLanguage *)langs->data;
+		if (langs != NULL)
+			spell->active_lang = (const GeditLanguage *)langs->data;
 	}
 
 	if (spell->active_lang != NULL)
@@ -602,7 +602,7 @@ gedit_spell_checker_check_word (GeditSpellChecker *spell,
 			res = TRUE;
 			break;
 		default:
-			g_return_val_if_fail (FALSE, FALSE);
+			g_return_val_if_reached (FALSE);
 	}
 
 	return res;
